==> release.12.2.28.1.tgz: cgi-cpn/prontus_tax_export_real.pl <==
#!/usr/bin/perl

# ---------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# ---------------------------------------------------------------

# -------------------------------COMENTARIO GLOBAL---------------
# ---------------------------------------------------------------
# PROPOSITO.
# -----------
# Exportar secciones, temas y subtemas a Prontus, hacia un archivo xml.
# ---------------------------------------------------------------
# LLAMADAS A ARCHIVOS EXTERNOS.
# ------------------------------
# No registra.
# ---------------------------------------------------------------
# INVOCACIONES ACEPTADAS.
# ------------------------
# Via system desde prontus_tax_export.cgi
# ---------------------------------------------------------------
# PLANTILLAS HTML UTILIZADAS.
# ----------------------------
# No utiliza.
# ---------------------------------------------------------------
# ---------------------------------------------------------------
# TABLAS UTILIZADAS.
# -------------------
# ART (BD prontus)
# ---------------------------------------------------------------
# -------------------------------BEGIN SCRIPT---------------
# ---------------------------------------------------------------
# DIRECTIVAS DE COMPILACION.
# ------------------------
use strict;
use utf8;

BEGIN {
    use FindBin qw($Bin);
    my $pathLibsProntus = $Bin;
    unshift(@INC,$pathLibsProntus);
}

##libs##
use lib_stdlog;
lib_stdlog::set_stdlog($0, 51200);
use prontus_varglb;
prontus_varglb::init();

use DBI;
use File::Copy;
use LockFile::Simple;
use glib_dbi_03;
use glib_fildir_03;
use glib_hrfec_03;
use glib_str_03;
use lib_bd;
use lib_lock;
use lib_logproc;
use lib_prontus;
use lib_utils;
##/libs##

my ($LOG_FILE, $PRONTUS_ID);
my ($BD, $LOCK_FILE);
my ($TOT_REGS, $OK_REGS) = (0, 0);
my (%FORM);
my $MODO_WEB = 0;

main: {
    lib_utils::setUtf8();

    if (scalar @ARGV < 2) {
        print "Parametros insuficientes Terminando\n";
        print "Uso: $0 [path_server] [nombre_prontus]\nPropósito: generar un archivo xml con las taxonomias para exportar.\n";
        exit;
    }

    if ($ARGV[0] && $ARGV[1]) {
        $prontus_varglb::DIR_SERVER = $ARGV[0];
        $PRONTUS_ID = $ARGV[1];
    }

    if (! -d $prontus_varglb::DIR_SERVER) {
        print STDERR "ERROR: DIR_SERVER no válido[$prontus_varglb::DIR_SERVER]\n";
        exit;
    }

    my $msg_load = lib_utils::load_config_by_id($PRONTUS_ID);
    if ($msg_load ne '') {
        print $msg_load;
        exit;
    }

    # Para el manejo del log de procesamiento
    $lib_logproc::LOG_FILE = "$prontus_varglb::DIR_SERVER$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_CPAN'}/procs/prontus_tax_export_log.html";
    $lib_logproc::MODO_WEB = $MODO_WEB;

    # Bloqueo
    $LOCK_FILE = "$prontus_varglb::DIR_SERVER$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_CPAN'}/procs/semaforo_tax_export";

    # Detecta semaforo.
    my $lock_obj = &lib_lock::lock_file($LOCK_FILE);
    if (!ref $lock_obj) { # si ya tiene un bloqueo anterior, aborta.
        &finishLoading("Proceso en ejecución. Por favor espere hasta que la exportación anterior termine.");
        lib_logproc::handle_error("Proceso en ejecución. Por favor espere hasta que la exportación anterior termine.");
    }

    # Mysql
    my ($msg_err_bd);
    ($BD, $msg_err_bd) = lib_bd::conectar_prontus_bd();
    if (!ref($BD)) {
        &finishLoading("ERROR: $msg_err_bd");
        lib_logproc::handle_error("ERROR: $msg_err_bd");
    }

    # Se realiza el proceso y se escribe al Log
    lib_logproc::flush_log();
    lib_logproc::writeRule();
    lib_logproc::add_to_log_count("INICIANDO PROCESO DE EXPORTACION");
    my $registros = &tax_export();
    lib_logproc::add_to_log_count("PROCESO DE EXPORTACION FINALIZADO");
    lib_logproc::writeRule();

    $TOT_REGS = '0' if ($TOT_REGS eq '');
    # &add_to_log("ready4save"); # debug
    glib_fildir_03::write_file("$prontus_varglb::DIR_SERVER$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_CPAN'}/procs/prontus_tax_export.xml", $registros);
    # &add_to_log("saved"); # debug
    sleep 1;
    lib_logproc::add_to_log("Nro. de registros exportados: $TOT_REGS\nPara bajar el archivo haga click <a href=\"$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_CPAN'}/procs/prontus_tax_export.xml\"download>aqu&iacute;</a>");
    lib_logproc::add_to_log_finish("Operaci&oacute;n finalizada.");

    $BD->disconnect;

    # Elimina el bloqueo y termina ejecucion.
    &lib_lock::unlock_file($lock_obj, $LOCK_FILE);

    # Se termina + el link para descargar
    &finishLoading('');
}

# ------------------------------------------------------------------------------
# SUB-RUTINAS.
# ------------------------------------------------------------------------------
# rotulos tax
sub tax_export {
    my ($sql);
    my ($salida_s, $salida_t, $salida_st);
    my ($id_s, $id_t, $id_st);
    my ($nom_s, $nom_t, $nom_st, $mostrar, $port, $orden, $nom4vistas);
    my ($nom_envistas);
    my ($registros) = "<?xml version='1.0' encoding='utf-8'?>\n<taxdata>\n";

    lib_logproc::add_to_log_count("Preparando datos a exportar.");

    $sql = "select SECC_ID, SECC_NOM, SECC_MOSTRAR, SECC_PORT, SECC_ORDEN, SECC_NOM4VISTAS from SECC order by SECC_ORDEN ASC, SECC_ID ASC";

    $salida_s = glib_dbi_03::ejecutar_sql_bind($BD, $sql, \($id_s, $nom_s, $mostrar, $port, $orden, $nom4vistas));

    lib_logproc::add_to_log_count("Exportaci&oacute;n iniciada");
    lib_logproc::writeRule();

    while ($salida_s->fetch) {
        # secciones
        glib_str_03::correct_encode_utf8_string($nom_s);
        glib_str_03::correct_encode_utf8_string($nom4vistas);
        $nom_s = lib_utils::escape_xml($nom_s);

            if ($mostrar) { $mostrar = 'SI'; } else { $mostrar = 'NO'; }

            $nom_envistas = &get_nom_envistas($nom4vistas);
            $port =~ s/&/&amp;/g; # Para que las url con & no boten el XML
            $orden = 1 if ($orden < 1); # orden no puede ser menor que 1, no se listan las taxonomias

            $registros .= "<seccion id='$id_s'>\n"
            . "<nom>$nom_s</nom>\n"
            . $nom_envistas
            . "<mostrar>$mostrar</mostrar>\n"
            . "<port>$port</port>\n"
            . "<posmapa>$orden</posmapa>\n";

            $TOT_REGS++;
            lib_logproc::add_to_log_count("Nro. de registros exportados: $TOT_REGS.");

            # temas
            my @params = ($id_s);
            $sql = "select TEMAS_ID, TEMAS_NOM, TEMAS_MOSTRAR, TEMAS_PORT, TEMAS_ORDEN, TEMAS_NOM4VISTAS from TEMAS WHERE TEMAS_IDSECC = ? order by TEMAS_NOM ASC, TEMAS_ID ASC";
            $salida_t = glib_dbi_03::ejecutar_sql_bind_param($BD, $sql, \@params, \($id_t, $nom_t, $mostrar, $port, $orden, $nom4vistas));

            while ($salida_t->fetch) {
                if ($mostrar) { $mostrar = 'SI'; } else { $mostrar = 'NO'; }

                glib_str_03::correct_encode_utf8_string($nom_t);
                glib_str_03::correct_encode_utf8_string($nom4vistas);
                $nom_t = lib_utils::escape_xml($nom_t);
                $nom_envistas = &get_nom_envistas($nom4vistas);
                $orden = 1 if ($orden < 1); # orden no puede ser menor que 1, no se listan las taxonomias

                $registros .= "<tema id='$id_t'>\n"
                . "<nom>$nom_t</nom>\n"
                . $nom_envistas
                . "<mostrar>$mostrar</mostrar>\n"
                . "<port>$port</port>\n"
                . "<posmapa>$orden</posmapa>\n";

                $TOT_REGS++;
                lib_logproc::add_to_log_count("Nro. de registros exportados: $TOT_REGS.");

                # subtemas
                @params = ($id_t);
                $sql = "select SUBTEMAS_ID, SUBTEMAS_NOM, SUBTEMAS_MOSTRAR, SUBTEMAS_PORT, SUBTEMAS_ORDEN, SUBTEMAS_NOM4VISTAS from SUBTEMAS WHERE SUBTEMAS_IDTEMAS = ? order by SUBTEMAS_NOM ASC, SUBTEMAS_ID ASC";
                $salida_st = glib_dbi_03::ejecutar_sql_bind_param($BD, $sql, \@params, \($id_st, $nom_st, $mostrar, $port, $orden, $nom4vistas));

                while ($salida_st->fetch) {
                    if ($mostrar) { $mostrar = 'SI'; } else { $mostrar = 'NO'; }

                    glib_str_03::correct_encode_utf8_string($nom_st);
                    glib_str_03::correct_encode_utf8_string($nom4vistas);
                    $nom_st = lib_utils::escape_xml($nom_st);
                    $nom_envistas = &get_nom_envistas($nom4vistas);
                    $orden = 1 if ($orden < 1); # orden no puede ser menor que 1, no se listan las taxonomias

                    $registros .= "<subtema id='$id_st'>\n"
                    . "<nom>$nom_st</nom>\n"
                    . $nom_envistas
                    . "<mostrar>$mostrar</mostrar>\n"
                    . "<port>$port</port>\n"
                    . "<posmapa>$orden</posmapa>\n"
                    . "</subtema>\n";

                    $TOT_REGS++;
                    lib_logproc::add_to_log_count("Nro. de registros exportados: $TOT_REGS.");
                }

                $salida_st->finish;
                $registros .= "</tema>\n";
            }

            $salida_t->finish;
            $registros .= "</seccion>\n";
        }

        $salida_s->finish;
        $registros .= "</taxdata>";

        return ($registros);
}

# ------------------------------------------------------------------------------
sub get_nom_envistas {
    my ($nom4vistas) = shift;
    my $nombres;

    foreach my $mv (keys %{$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'MULTIVISTAS'}}) {
        my $nom = lib_prontus::get_nomtax_envista($mv, $nom4vistas);
        $nom = lib_utils::escape_xml($nom);
        $nombres .= "<nom-$mv>" . $nom . "</nom-$mv>\n";
    }

    return $nombres;
}

# ------------------------------------------------------------------------------
sub finishLoading {
    my $msg = $_[0];
    my $result_file = "$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_CPAN'}/procs/result_tax_export.json";

    $msg = '{"status":1, "msg":"'.$msg.'"}';

    glib_fildir_03::write_file("$prontus_varglb::DIR_SERVER$result_file", $msg);
}

==> release.12.3.1.2.tgz: cgi-cpn/prontus_tax_export_real.pl <==
#!/usr/bin/perl

# ---------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# ---------------------------------------------------------------

# -------------------------------COMENTARIO GLOBAL---------------
# ---------------------------------------------------------------
# PROPOSITO.
# -----------
# Exportar secciones, temas y subtemas a Prontus, hacia un archivo xml.
# ---------------------------------------------------------------
# LLAMADAS A ARCHIVOS EXTERNOS.
# ------------------------------
# No registra.
# ---------------------------------------------------------------
# INVOCACIONES ACEPTADAS.
# ------------------------
# Via system desde prontus_tax_export.cgi
# ---------------------------------------------------------------
# PLANTILLAS HTML UTILIZADAS.
# ----------------------------
# No utiliza.
# ---------------------------------------------------------------
# ---------------------------------------------------------------
# TABLAS UTILIZADAS.
# -------------------
# ART (BD prontus)
# ---------------------------------------------------------------
# -------------------------------BEGIN SCRIPT---------------
# ---------------------------------------------------------------
# DIRECTIVAS DE COMPILACION.
# ------------------------
use strict;
use utf8;

BEGIN {
    use FindBin qw($Bin);
    my $pathLibsProntus = $Bin;
    unshift(@INC,$pathLibsProntus);
}

##libs##
use lib_stdlog;
lib_stdlog::set_stdlog($0, 51200);
use prontus_varglb;
prontus_varglb::init();

use DBI;
use File::Copy;
use JSON;
use LockFile::Simple;
use glib_dbi_03;
use glib_fildir_03;
use glib_hrfec_03;
use glib_str_03;
use lib_bd;
use lib_encodes;
use lib_lang;
use lib_lock;
use lib_logproc;
use lib_prontus;
use lib_utils;
##/libs##

my ($LOG_FILE, $PRONTUS_ID);
my ($BD, $LOCK_FILE);
my ($TOT_REGS, $OK_REGS) = (0, 0);

main: {
    lib_utils::setUp();
    if (scalar @ARGV < 2) {
        print lib_lang::get_message('global_insufficient_arguments');
        print lib_lang::get_interpolated_message("tax_export_real_use", $0);
        exit;
    }

    if ($ARGV[0] && $ARGV[1]) {
        $prontus_varglb::DIR_SERVER = $ARGV[0];
        $PRONTUS_ID = $ARGV[1];
    }

    if (! -d $prontus_varglb::DIR_SERVER) {
        print STDERR lib_lang::get_message('global_error_invalid_dir')."\n";
        exit;
    }

    my $msg_load = lib_utils::load_config_by_id($PRONTUS_ID);
    if ($msg_load ne '') {
        print $msg_load;
        exit;
    }

    # Para el manejo del log de procesamiento
    $lib_logproc::LOG_FILE = "$prontus_varglb::DIR_SERVER$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_CPAN'}/procs/prontus_tax_export_log.html";
    $lib_logproc::JS_FILE  = "$prontus_varglb::DIR_SERVER$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_CPAN'}/procs/result_tax_export.json";

    # Bloqueo
    $LOCK_FILE = "$prontus_varglb::DIR_SERVER$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_CPAN'}/procs/semaforo_tax_export";

    # Detecta semaforo.
    my $lock_obj = &lib_lock::lock_file($LOCK_FILE);
    if (!ref $lock_obj) { # si ya tiene un bloqueo anterior, aborta.
        my $msg = lib_lang::get_message("global_previous_export");
        lib_logproc::finishLoading($msg);
        lib_logproc::handle_error($msg);
    }

    # Mysql
    my ($msg_err_bd);
    ($BD, $msg_err_bd) = lib_bd::conectar_prontus_bd();
    if (!ref($BD)) {
        lib_logproc::finishLoading($msg_err_bd);
        lib_logproc::handle_error($msg_err_bd);
    }

    # Se realiza el proceso y se escribe al Log
    lib_logproc::writeRule();
    lib_logproc::add_to_log_count(lib_lang::get_message("global_export_starting"));
    my $registros = &tax_export();
    lib_logproc::add_to_log_count(lib_lang::get_message("global_export_ending"));
    lib_logproc::writeRule();

    $TOT_REGS = '0' if ($TOT_REGS eq '');
    # &add_to_log("ready4save"); # debug
    glib_fildir_03::write_file("$prontus_varglb::DIR_SERVER$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_CPAN'}/procs/prontus_tax_export.xml", $registros);
    # &add_to_log("saved"); # debug
    sleep 1;
    my $msg = lib_lang::get_interpolated_message('global_export_download_message', $TOT_REGS) .
        "<a href=\"$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_CPAN'}/procs/prontus_tax_export.xml\" download> " .
        lib_lang::get_message('global_export_download_message_link') .'</a>';
    lib_logproc::add_to_log($msg);
    lib_logproc::add_to_log_finish(lib_lang::get_message('global_finalized'));

    $BD->disconnect;

    # Elimina el bloqueo y termina ejecucion.
    &lib_lock::unlock_file($lock_obj, $LOCK_FILE);

    # Se termina + el link para descargar
    lib_logproc::finishLoading('');
}

# ------------------------------------------------------------------------------
# SUB-RUTINAS.
# ------------------------------------------------------------------------------
# rotulos tax
sub tax_export {
    my ($id_s, $id_t, $id_st, $nom_s, $nom_t, $nom_st, $mostrar, $port, $orden, $nom4vistas);
    my $registros = "<?xml version='1.0' encoding='utf-8'?>\n<taxdata>\n";

    lib_logproc::add_to_log_count(lib_lang::get_message("global_export_preparing_data"));

    my $secc_table = lib_utils::get_table('secc');
    my $sql = "select secc_id, secc_nom, secc_mostrar, secc_port, secc_orden, secc_nom4vistas from $secc_table order by secc_orden asc, secc_id asc";
    my $salida_s = glib_dbi_03::ejecutar_sql_bind($BD, $sql, \($id_s, $nom_s, $mostrar, $port, $orden, $nom4vistas));

    lib_logproc::add_to_log_count(lib_lang::get_message('global_export_export_started'));
    lib_logproc::writeRule();

    my $temas_table = lib_utils::get_table('temas');
    my $subtemas_table = lib_utils::get_table('subtemas');
    while ($salida_s->fetch) {
        # secciones
        glib_str_03::correct_encode_utf8_string($nom_s);
        glib_str_03::correct_encode_utf8_string($nom4vistas);
        $nom_s = lib_encodes::escape_xml($nom_s);

            if ($mostrar) { $mostrar = 'SI'; } else { $mostrar = 'NO'; }

            my $nom_envistas = &get_nom_envistas($nom4vistas);
            $port =~ s/&/&amp;/g; # Para que las url con & no boten el XML
            $orden = 1 if ($orden < 1); # orden no puede ser menor que 1, no se listan las taxonomias

            $registros .= "<seccion id='$id_s'>\n"
            . "<nom>$nom_s</nom>\n"
            . $nom_envistas
            . "<mostrar>$mostrar</mostrar>\n"
            . "<port>$port</port>\n"
            . "<posmapa>$orden</posmapa>\n";

            $TOT_REGS++;
            lib_logproc::add_to_log_count(lib_lang::get_interpolated_message("global_export_exported_records", $TOT_REGS));

            # temas
            my @params = ($id_s);
            $sql = "select temas_id, temas_nom, temas_mostrar, temas_port, temas_orden, temas_nom4vistas from $temas_table where temas_idsecc = ? order by temas_nom asc, temas_id asc";
            my $salida_t = glib_dbi_03::ejecutar_sql_bind_param($BD, $sql, \@params, \($id_t, $nom_t, $mostrar, $port, $orden, $nom4vistas));

            while ($salida_t->fetch) {
                if ($mostrar) { $mostrar = 'SI'; } else { $mostrar = 'NO'; }

                glib_str_03::correct_encode_utf8_string($nom_t);
                glib_str_03::correct_encode_utf8_string($nom4vistas);
                $nom_t = lib_encodes::escape_xml($nom_t);
                $nom_envistas = &get_nom_envistas($nom4vistas);
                $orden = 1 if ($orden < 1); # orden no puede ser menor que 1, no se listan las taxonomias

                $registros .= "<tema id='$id_t'>\n"
                . "<nom>$nom_t</nom>\n"
                . $nom_envistas
                . "<mostrar>$mostrar</mostrar>\n"
                . "<port>$port</port>\n"
                . "<posmapa>$orden</posmapa>\n";

                $TOT_REGS++;
                lib_logproc::add_to_log_count(lib_lang::get_interpolated_message("global_export_exported_records", $TOT_REGS));

                # subtemas
                @params = ($id_t);
                $sql = "select subtemas_id, subtemas_nom, subtemas_mostrar, subtemas_port, subtemas_orden, subtemas_nom4vistas from $subtemas_table where subtemas_idtemas = ? order by subtemas_nom asc, subtemas_id asc";
                my $salida_st = glib_dbi_03::ejecutar_sql_bind_param($BD, $sql, \@params, \($id_st, $nom_st, $mostrar, $port, $orden, $nom4vistas));

                while ($salida_st->fetch) {
                    if ($mostrar) { $mostrar = 'SI'; } else { $mostrar = 'NO'; }

                    glib_str_03::correct_encode_utf8_string($nom_st);
                    glib_str_03::correct_encode_utf8_string($nom4vistas);
                    $nom_st = lib_encodes::escape_xml($nom_st);
                    $nom_envistas = &get_nom_envistas($nom4vistas);
                    $orden = 1 if ($orden < 1); # orden no puede ser menor que 1, no se listan las taxonomias

                    $registros .= "<subtema id='$id_st'>\n"
                    . "<nom>$nom_st</nom>\n"
                    . $nom_envistas
                    . "<mostrar>$mostrar</mostrar>\n"
                    . "<port>$port</port>\n"
                    . "<posmapa>$orden</posmapa>\n"
                    . "</subtema>\n";

                    $TOT_REGS++;
                    lib_logproc::add_to_log_count(lib_lang::get_interpolated_message("global_export_exported_records", $TOT_REGS));
                }

                $salida_st->finish;
                $registros .= "</tema>\n";
            }

            $salida_t->finish;
            $registros .= "</seccion>\n";
        }

        $salida_s->finish;
        $registros .= "</taxdata>";

        return ($registros);
}

# ------------------------------------------------------------------------------
sub get_nom_envistas {
    my ($nom4vistas) = shift;
    my $nombres;

    foreach my $mv (keys %{$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'MULTIVISTA'}}) {
        my $nom = lib_prontus::get_nomtax_envista($mv, $nom4vistas);
        $nom = lib_encodes::escape_xml($nom);
        $nombres .= "<nom-$mv>" . $nom . "</nom-$mv>\n";
    }

    return $nombres;
}
